@@ -1,21 +1,21 @@
 /*
-  SPDX-FileCopyrightText: 2017-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2017-2021 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "logactivitiesdialog.h"
-#include "logactivitieswidget.h"
 #include "logactivitiesmanager.h"
 #include "logactivitiespurposemenuwidget.h"
-#include <PimCommon/PimUtil>
-#include <KLocalizedString>
+#include "logactivitieswidget.h"
 #include <KConfigGroup>
+#include <KLocalizedString>
 #include <KSharedConfig>
-#include <QVBoxLayout>
+#include <PimCommon/PimUtil>
+#include <QCheckBox>
 #include <QDialogButtonBox>
 #include <QPushButton>
-#include <QCheckBox>
+#include <QVBoxLayout>
 
 using namespace PimCommon;
 
@@ -23,7 +23,7 @@ LogActivitiesDialog::LogActivitiesDialog(QWidget *parent)
     : QDialog(parent)
 {
     setWindowTitle(i18nc("@title:window", "Log activities"));
-    auto *mainLayout = new QVBoxLayout(this);
+    auto mainLayout = new QVBoxLayout(this);
     mainLayout->setObjectName(QStringLiteral("mainLayout"));
 
     mLogWidget = new LogActivitiesWidget(this);
@@ -35,7 +35,7 @@ LogActivitiesDialog::LogActivitiesDialog(QWidget *parent)
     mainLayout->addWidget(mEnableLogActivities);
     connect(mEnableLogActivities, &QCheckBox::toggled, this, &LogActivitiesDialog::slotEnableLogActivities);
 
-    QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Close | QDialogButtonBox::Save, this);
+    auto buttonBox = new QDialogButtonBox(QDialogButtonBox::Close | QDialogButtonBox::Save, this);
     buttonBox->setObjectName(QStringLiteral("buttonbox"));
 
     mClearButton = new QPushButton(i18n("Clear"), this);
@@ -46,7 +46,7 @@ LogActivitiesDialog::LogActivitiesDialog(QWidget *parent)
     mSaveButton->setObjectName(QStringLiteral("savebutton"));
     mSaveButton->setEnabled(false);
 
-    auto *purposeMenu = new LogactivitiesPurposeMenuWidget(this, this);
+    auto purposeMenu = new LogactivitiesPurposeMenuWidget(this, this);
     mShareButton = new QPushButton(i18n("Share..."), this);
     mShareButton->setMenu(purposeMenu->menu());
     mShareButton->setIcon(QIcon::fromTheme(QStringLiteral("document-share")));
@@ -81,8 +81,7 @@ void LogActivitiesDialog::slotActivityTextChanged(bool changed)
 void LogActivitiesDialog::slotSave()
 {
     const QString filter = i18n("All Files (*)");
-    PimCommon::Util::saveTextAs(PimCommon::LogActivitiesManager::self()->log(), filter, this, QUrl(),
-                                i18nc("@title:window", "Save Log"));
+    PimCommon::Util::saveTextAs(PimCommon::LogActivitiesManager::self()->log(), filter, this, QUrl(), i18nc("@title:window", "Save Log"));
 }
 
 void LogActivitiesDialog::slotEnableLogActivities(bool state)
