@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2017-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2017-2021 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -7,18 +7,19 @@
 #ifndef LOGACTIVITIESDIALOG_H
 #define LOGACTIVITIESDIALOG_H
 
-#include <QDialog>
 #include "pimcommon_private_export.h"
+#include <QDialog>
 class QPushButton;
 class QCheckBox;
-namespace PimCommon {
+namespace PimCommon
+{
 class LogActivitiesWidget;
 class PIMCOMMON_TESTS_EXPORT LogActivitiesDialog : public QDialog
 {
     Q_OBJECT
 public:
     explicit LogActivitiesDialog(QWidget *parent = nullptr);
-    ~LogActivitiesDialog();
+    ~LogActivitiesDialog() override;
 
     void setLog(const QString &str);
 
