@@ -1,26 +1,14 @@
 /*
-  Copyright (c) 2012-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2012-2021 Laurent Montel <montel@kde.org>
 
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+  SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "googletranslator.h"
-#include "translatorutil.h"
-#include "translatordebugdialog.h"
-#include <KLocalizedString>
 #include "pimcommon_debug.h"
+#include "translatordebugdialog.h"
+#include "translatorutil.h"
+#include <KLocalizedString>
 #include <QJsonParseError>
 #include <QNetworkAccessManager>
 #include <QNetworkRequest>
@@ -69,12 +57,12 @@ QString GoogleTranslator::resultTranslate() const
     return mResult;
 }
 
-QMap<QString, QMap<QString, QString> > GoogleTranslator::initListLanguage(QComboBox *from)
+QMap<QString, QMap<QString, QString>> GoogleTranslator::initListLanguage(QComboBox *from)
 {
-    QMap<QString, QMap<QString, QString> > listLanguage;
+    QMap<QString, QMap<QString, QString>> listLanguage;
 
     TranslatorUtil translatorUtil;
-    QVector<QPair<QString, QString> > fullListLanguage;
+    QVector<QPair<QString, QString>> fullListLanguage;
     fullListLanguage.append(translatorUtil.pair(TranslatorUtil::automatic));
     fullListLanguage.append(translatorUtil.pair(TranslatorUtil::en));
     fullListLanguage.append(translatorUtil.pair(TranslatorUtil::nl));
@@ -142,7 +130,7 @@ QMap<QString, QMap<QString, QString> > GoogleTranslator::initListLanguage(QCombo
 
         QMap<QString, QString> toList;
         for (int j = 0; j < fullListLanguageSize; ++j) {
-            if (j != 0 && j != i) { //don't add auto and current language
+            if (j != 0 && j != i) { // don't add auto and current language
                 translatorUtil.addPairToMap(toList, fullListLanguage.at(j));
             }
         }
@@ -197,7 +185,7 @@ void GoogleTranslator::slotTranslateFinished(QNetworkReply *reply)
     //  but this is not valid JSON for QJSON, it expects empty strings: ["foo","","bar"]
     mJsonData.replace(QRegExp(QLatin1String(",{3,3}")), QStringLiteral(",\"\",\"\","));
     mJsonData.replace(QRegExp(QLatin1String(",{2,2}")), QStringLiteral(",\"\","));
-    //qCDebug(PIMCOMMON_LOG) << mJsonData;
+    // qCDebug(PIMCOMMON_LOG) << mJsonData;
 
     QJsonParseError parsingError;
     const QJsonDocument jsonDoc = QJsonDocument::fromJson(mJsonData.toUtf8(), &parsingError);
