@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2012-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2012-2021 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -7,23 +7,24 @@
 #ifndef GOOGLETRANSLATOR_H
 #define GOOGLETRANSLATOR_H
 
-#include <QObject>
 #include <QNetworkReply>
+#include <QObject>
 class QNetworkAccessManager;
 class QComboBox;
 class QNetworkReply;
 
-namespace PimCommon {
+namespace PimCommon
+{
 class GoogleTranslator : public QObject
 {
     Q_OBJECT
 public:
     explicit GoogleTranslator(QObject *parent = nullptr);
-    ~GoogleTranslator();
+    ~GoogleTranslator() override;
 
     void setParentWidget(QWidget *parent);
 
-    Q_REQUIRED_RESULT QMap<QString, QMap<QString, QString> > initListLanguage(QComboBox *from);
+    Q_REQUIRED_RESULT QMap<QString, QMap<QString, QString>> initListLanguage(QComboBox *from);
     void translate();
     void debug();
     void clear();
