@@ -10,25 +10,25 @@
 
 #include "imapresourcesettings.h"
 
-#include <QFileDialog>
-#include <QDesktopServices>
-#include <KMessageBox>
-#include <KLocalizedString>
 #include <KEmailAddress>
+#include <KLocalizedString>
+#include <KMessageBox>
+#include <QDesktopServices>
+#include <QFileDialog>
 
-#include <QTextStream>
-#include <QWidget>
 #include <QPointer>
+#include <QTextStream>
 #include <QUrlQuery>
+#include <QWidget>
 
 #include <errno.h>
 
 OrgKdeAkonadiImapSettingsInterface *PimCommon::Util::createImapSettingsInterface(const QString &ident)
 {
     if (isImapResource(ident)) {
-        return
-            new OrgKdeAkonadiImapSettingsInterface(
-            QLatin1String("org.freedesktop.Akonadi.Resource.") + ident, QStringLiteral("/Settings"), QDBusConnection::sessionBus());
+        return new OrgKdeAkonadiImapSettingsInterface(QLatin1String("org.freedesktop.Akonadi.Resource.") + ident,
+                                                      QStringLiteral("/Settings"),
+                                                      QDBusConnection::sessionBus());
     } else {
         return nullptr;
     }
@@ -62,7 +62,9 @@ bool PimCommon::Util::saveToFile(const QString &filename, const QString &text)
         return false;
     }
     QTextStream out(&file);
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     out.setCodec("UTF-8");
+#endif
     out << text;
     file.close();
     return true;
@@ -97,9 +99,8 @@ QString PimCommon::Util::loadToFile(const QString &filter, QWidget *parent, cons
 
 bool PimCommon::Util::isImapResource(const QString &identifier)
 {
-    return identifier.startsWith(KOLAB_RESOURCE_IDENTIFIER)
-           || identifier.startsWith(IMAP_RESOURCE_IDENTIFIER)
-           || identifier.startsWith(GMAIL_RESOURCE_IDENTIFIER);
+    return identifier.startsWith(KOLAB_RESOURCE_IDENTIFIER) || identifier.startsWith(IMAP_RESOURCE_IDENTIFIER)
+        || identifier.startsWith(GMAIL_RESOURCE_IDENTIFIER);
 }
 
 void PimCommon::Util::invokeHelp(const QString &docfile, const QString &anchor)
@@ -120,9 +121,7 @@ void PimCommon::Util::invokeHelp(const QString &docfile, const QString &anchor)
 QStringList PimCommon::Util::generateEmailList(const QStringList &list)
 {
     QString str;
-    const int numberOfElement{
-        list.count()
-    };
+    const int numberOfElement{list.count()};
     for (int i = 0; i < numberOfElement; i++) {
         QString tmpStr = list.at(i);
         if (!tmpStr.trimmed().isEmpty()) {
