@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2017-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2017-2021 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -7,10 +7,11 @@
 #ifndef LINEEDITWITHCOMPLETERNG_H
 #define LINEEDITWITHCOMPLETERNG_H
 
-#include <QLineEdit>
 #include "pimcommon_export.h"
+#include <QLineEdit>
 class QStringListModel;
-namespace PimCommon {
+namespace PimCommon
+{
 /**
  * @brief The LineEditWithCompleterNg class
  * @author Laurent Montel <montel@kde.org>
