@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -7,9 +7,10 @@
 #ifndef ACLLISTVIEW_H
 #define ACLLISTVIEW_H
 
-#include <QListView>
 #include "pimcommonakonadi_private_export.h"
-namespace PimCommon {
+#include <QListView>
+namespace PimCommon
+{
 class PIMCOMMONAKONADI_TESTS_EXPORT AclListView : public QListView
 {
     Q_OBJECT
