@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2017-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2017-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -7,21 +7,23 @@
 #ifndef ADDRESSEELINEEDITLDAP_H
 #define ADDRESSEELINEEDITLDAP_H
 
-#include <QTimer>
 #include <QMap>
+#include <QTimer>
 
-namespace KLDAP {
+namespace KLDAP
+{
 class LdapClientSearch;
 }
 
-namespace PimCommon {
+namespace PimCommon
+{
 class AddresseeLineEditManager;
 class AddresseeLineEdit;
 class AddresseeLineEditLdap : public QObject
 {
 public:
     explicit AddresseeLineEditLdap(AddresseeLineEditManager *addressLineStatic, QObject *parent = nullptr);
-    ~AddresseeLineEditLdap();
+    ~AddresseeLineEditLdap() override;
 
     void init();
 
@@ -43,6 +45,7 @@ public:
     void startLoadingLDAPEntries();
     void stopLDAPLookup();
     void restartLdap(const QString &searchString, AddresseeLineEdit *addressLine);
+
 private:
     // maps LDAP client indices to completion source indices
     // the assumption that they are always the first n indices in s_static->completion
