@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: LGPL-2.0-or-later
 
@@ -9,14 +9,15 @@
 #define RECENTADDRESSWIDGET_H
 
 #include "pimcommonakonadi_export.h"
-#include <QWidget>
 #include <QStringList>
+#include <QWidget>
 class KConfig;
 class QListWidget;
 class QLineEdit;
 class QToolButton;
 
-namespace PimCommon {
+namespace PimCommon
+{
 /**
  * @brief The RecentAddressWidget class
  * @author Laurent Montel <montel@kde.org>
