@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2014-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2014-2021 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: LGPL-2.0-or-later
 
@@ -8,9 +8,10 @@
 #ifndef CONTENTTYPEWIDGET_H
 #define CONTENTTYPEWIDGET_H
 
-#include <QWidget>
 #include "pimcommonakonadi_export.h"
-namespace PimCommon {
+#include <QWidget>
+namespace PimCommon
+{
 class ContentTypeWidgetPrivate;
 /**
  * @brief The ContentTypeWidget class
@@ -21,7 +22,7 @@ class PIMCOMMONAKONADI_EXPORT ContentTypeWidget : public QWidget
     Q_OBJECT
 public:
     explicit ContentTypeWidget(QWidget *parent = nullptr);
-    ~ContentTypeWidget();
+    ~ContentTypeWidget() override;
 
     Q_REQUIRED_RESULT int currentIndex() const;
     void setCurrentIndex(int index);
