@@ -10,7 +10,8 @@
 #include <Libkdepim/ProgressManager> // ProgressItem
 
 #include <AgentInstance>
-namespace PimCommon {
+namespace PimCommon
+{
 /**
  * @internal
  *
@@ -24,7 +25,7 @@ class AgentProgressMonitor : public QObject
 public:
     // used by our friend ProgressManager
     AgentProgressMonitor(const Akonadi::AgentInstance &mAgent, KPIM::ProgressItem *mItem);
-    ~AgentProgressMonitor();
+    ~AgentProgressMonitor() override;
 
 private:
     void abort();
